#Plot time evolution of .xy.h5 quantities
import numpy as np
import matplotlib.pyplot as plt 
import matplotlib
import h5py
import math
import scidata.carpet.hdf5 as hdf5
from scipy import interpolate
import matplotlib.ticker as ticker
from matplotlib.ticker import NullFormatter
import matplotlib.gridspec as gridspec
from matplotlib.transforms import Affine2D
import mpl_toolkits.axisartist.floating_axes as floating_axes
import scipy

#function to extract the data from .xy.h5 files
def get_data(df,it,rl):
    grid = df.get_reflevel(iteration=it, reflevel=rl)
    x,y = grid.mesh()
    dat = df.get_reflevel_data(grid, iteration=it)
    return x, y, dat

#plot settings
params = {
    'figure.figsize'    : [16, 6.15],
    'legend.fontsize'   : 14,
    'text.usetex'       : True,
    'axes.titlesize' : 20,
    'axes.labelsize' : 20,  
    'xtick.labelsize' : 18 ,
    'ytick.labelsize' : 18 
}
matplotlib.rcParams.update(params)

#units
uc = 2.99792458*10**(10)
uG = 6.67428*10**(-8)
uMs = 1.9884*10**(33)
utime = uG*uMs/uc**3*1000
ulenght = (uG*uMs/uc**2)/100000
urho = (uc**6)/(uG**3*uMs**2)
normalnuc = 2.705*10**(14)

#read in the .h5 data
file = hdf5.dataset("./../data/Cow-dx04/rho.xy.h5")
itr_list=file.iterations

#defining the colormaps
cmap1 = plt.get_cmap("gist_ncar")
cmap2 = plt.get_cmap("nipy_spectral")

#loop over several iterations (times)
for i in range(0,3):
    
    #extract the data of the specified iteration
    IT = itr_list[i]
    x, y, density = get_data(file, IT, 0)
    print(i)

    #plotting grid
    plt.figure(0)
    gs = gridspec.GridSpec(1, 2, width_ratios=[1,1], wspace=0.20)#war0.08
    ax1 = plt.subplot(gs[0])
    ax2 = plt.subplot(gs[1])

    #plot data on ax1
    cm_1a = ax1.imshow(urho/normalnuc*density[3:].T[3:], vmin=0, vmax=3.5, cmap=cmap1, interpolation="bicubic", origin="lower", extent=(0, x.max()*ulenght, 0, y.max()*ulenght))
    cm_1b = ax1.imshow(urho/normalnuc*density[3:].T[3:], vmin=0, vmax=3.5, cmap=cmap1, interpolation="bicubic", origin="lower", extent=(0, -x.max()*ulenght, 0, y.max()*ulenght))
    cm_1c = ax1.imshow(urho/normalnuc*density[3:].T[3:], vmin=0, vmax=3.5, cmap=cmap1, interpolation="bicubic", origin="lower", extent=(0, x.max()*ulenght, 0, -y.max()*ulenght))
    cm_1d = ax1.imshow(urho/normalnuc*density[3:].T[3:], vmin=0, vmax=3.5, cmap=cmap1, interpolation="bicubic", origin="lower", extent=(0, -x.max()*ulenght, 0, -y.max()*ulenght))
    cbar1 = plt.colorbar(cm_1a,ax=ax1,ticks=[0,1,2,3,4,5],pad=0.02)
    cbar1.set_label(r'$\rm \rho/\!\rho_{0}$',size=20)
    #plot data on ax2
    cm_2a = ax2.imshow(np.log10(urho*density[3:].T[3:]), vmin=4.7, vmax=15.5, cmap=cmap2, interpolation="bicubic", origin="lower", extent=(0, x.max()*ulenght, 0, y.max()*ulenght))
    cm_2b = ax2.imshow(np.log10(urho*density[3:].T[3:]), vmin=4.7, vmax=15.5, cmap=cmap2, interpolation="bicubic", origin="lower", extent=(0, -x.max()*ulenght, 0, y.max()*ulenght))
    cm_2c = ax2.imshow(np.log10(urho*density[3:].T[3:]), vmin=4.7, vmax=15.5, cmap=cmap2, interpolation="bicubic", origin="lower", extent=(0, x.max()*ulenght, 0, -y.max()*ulenght))
    cm_2d = ax2.imshow(np.log10(urho*density[3:].T[3:]), vmin=4.7, vmax=15.5, cmap=cmap2, interpolation="bicubic", origin="lower", extent=(0, -x.max()*ulenght, 0, -y.max()*ulenght))
    cbar2 = plt.colorbar(cm_2a,ax=ax2,ticks=[0,2.5,5,7.5,10,12.5,15],pad=0.02)
    cbar2.set_label(r'$\rm log(\rho) \,[g/cm^3]$',size=20)

    #set labels, ...
    ax1.set_xlabel(r'$\rm x \,[km]$')
    ax2.set_xlabel(r'$\rm x \,[km]$')
    ax1.set_ylabel(r'$\rm y \,[km]$')
    ax2.set_ylabel(r'$\rm y \,[km]$')
    ax1.set_xlim([-17,17])
    ax1.set_ylim([-17,17])
    ax2.set_xlim([-24.9,24.9])
    ax2.set_ylim([-24.9,24.9])
    ax1.set_xticks([-15,-10,-5,0,5,10,15])
    ax1.set_yticks([-15,-10,-5,0,5,10,15])
    ax2.set_xticks([-20,-15,-10,-5,0,5,10,15,20])
    ax2.set_yticks([-20,-15,-10,-5,0,5,10,15,20])
    
    #save figure
    saveFig = "./dichte-{:03d}.jpg".format(i)
    plt.savefig(saveFig, dpi=400,bbox_inches="tight",pad_inches=0.05,format="jpg")
